@@ -31,6 +31,8 @@ setMethod(f = "getCRS",
 
 # geom ----
 #' @rdname getCRS
+#' @examples
+#' getCRS(x = gtGeoms$grid$continuous)
 #' @export
 setMethod(f = "getCRS",
           signature = "geom",
@@ -51,6 +53,11 @@ setMethod(f = "getCRS",
 
 # sf ----
 #' @rdname getCRS
+#' @examples
+#'
+#' library(sf)
+#' nc_sf <- st_read(system.file("shape/nc.shp", package="sf"), quiet = TRUE)
+#' getCRS(nc_sf)
 #' @importFrom sf st_crs
 #' @export
 setMethod(f = "getCRS",
@@ -60,19 +67,11 @@ setMethod(f = "getCRS",
           }
 )
 
-# ppp ----
-#' @rdname getCRS
-#' @importFrom sf st_crs
-#' @export
-setMethod(f = "getCRS",
-          signature = "ppp",
-          definition = function(x){
-            as.character(NA)
-          }
-)
-
 # Raster ----
 #' @rdname getCRS
+#' @examples
+#'
+#' getCRS(x = gtRasters$categorical)
 #' @export
 setMethod(f = "getCRS",
           signature = 'Raster',
