@@ -1,3 +1,3 @@
 #' @useDynLib geometr
 globalVariables(c("x", "y", "gtTheme", "fid", "gid", "vid", "targetGrob",
-                  "include", "L1", "L2", "L3", "is_dup", "is_odd"))
\ No newline at end of file
+                  "include", "L1", "L2", "L3", "is_dup", "is_odd", "value"))
\ No newline at end of file
