@@ -16,14 +16,12 @@ test_that("setGroups of a 'geom'", {
   # set table with a known variable
   output <- setGroups(x = input, table = attributes)
   expect_class(output, "geom")
-  expect_list(output@feature, len = 1)
-  expect_names(names(output@group$geometry), must.include = c("gid", "data"))
+  expect_names(names(output@group), must.include = c("gid", "data"))
 
   # set table with only unknown variables
   output <- setGroups(x = input, table = data.frame(gid = 1, data = "B"))
   expect_class(output, "geom")
-  expect_list(output@feature, len = 1)
-  expect_names(names(output@group$geometry), must.include = c("gid", "data"))
+  expect_names(names(output@group), must.include = c("gid", "data"))
 })
 
 test_that("setGroups of a 'RasterLayer'", {
